"""Install tensor2tensor."""

from setuptools import find_packages
from setuptools import setup

setup(
    name='tensor2tensorM',
    version='2.0.0',
    description='Tensor2TensorM',
    author='Manuel Garcia',
    author_email='manuel.garcia02@uptc.edu.co',
    url='https://github.com/manuel3265/tensor',
    license='Apache 2.0',
    packages=find_packages(),
    package_data={
        'tensor2tensor.data_generators': ['test_data/*'],
        'tensor2tensor.data_generators.wikisum': ['test_data/*'],
        'tensor2tensor.visualization': [
            'attention.js', 'TransformerVisualization.ipynb'
        ],
    },
    scripts=[
        'tensor2tensor/bin/t2t-trainer',
        'tensor2tensor/bin/t2t-datagen',
        'tensor2tensor/bin/t2t-decoder',
        'tensor2tensor/bin/t2t-make-tf-configs',
        'tensor2tensor/bin/t2t-eval',
        'tensor2tensor/bin/t2t-exporter',
        'tensor2tensor/bin/t2t-query-server',
        'tensor2tensor/bin/t2t-insights-server',
        'tensor2tensor/bin/t2t-avg-all',
        'tensor2tensor/bin/t2t-bleu',
        'tensor2tensor/bin/t2t-translate-all',
        'tensor2tensor/bin/init_server'
    ],
    install_requires=[
        'bz2file',
        'dopamine-rl',
        'flask',
        'future',
        'gevent',
        'google-api-python-client',
        'gunicorn',
        'gym',
        'h5py',
        'mesh-tensorflow',
        'numpy',
        'oauth2client',
        'opencv-python',
        'requests',
        'scipy',
        'six',
        'sympy',
        'tensorflow-probability',
        'tf-agents',
        'tfds-nightly',
        'tqdm',
        'pypng',
        'matplotlib',
        'pydub',
        'IPython',
    ],
    extras_require={
        'tensorflow': ['tensorflow>=1.12.0'],
        'tensorflow_gpu': ['tensorflow-gpu>=1.12.0'],
        'tensorflow-hub': ['tensorflow-hub>=0.1.1'],
        'tests': [
            'absl-py',
            'pytest>=3.8.0',
            'mock',
            'pylint',
            'jupyter',
            'gsutil',
            'matplotlib',
            # Need atari extras for Travis tests, but because gym is already in
            # install_requires, pip skips the atari extras, so we instead do an
            # explicit pip install gym[atari] for the tests.
            # 'gym[atari]',
        ],
        'allen': ['Pillow==5.1.0', 'pandas==0.23.0'],
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
    ],
    dependency_links=[
        'git+https://github.com/manuel3265/tensor.git#egg=cleverhans'
    ],
    keywords='tensorflow machine learning',
)

